%% Draw Mohr's circle in 2D
% Usage: Mohr_tool

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press
%
% Please refer to the online manual for detailed usage instructions

%--------------------------------------------------------------------------
% Substantially modified from a script authored by Mark Tschopp, January, 2010
%
% Downloaded from MATLAB Central on 16 April, 2013
%--------------------------------------------------------------------------

close all;

% Input dialog box 

prompt={'\sigma_1 (MPa)','\sigma_2 (MPa)','\sigma_3 (MPa)','Pore pressure (MPa)','C_0 (MPa)','C_1 (MPa)','\mu_0','\mu_1'};
name='Input for Mohr circle';
numlines=1;
defaultanswer={'80','50','40','20','10','2','0.6','0.4'};
options.Resize='on';
options.WindowStyle='normal';
options.Interpreter='tex';
answer=inputdlg(prompt,name,numlines,defaultanswer,options);

sig1 = str2double(answer(1));
sig2 = str2double(answer(2));
sig3 = str2double(answer(3));
P = str2double(answer(4));
C = str2double(answer(5));
C1 = str2double(answer(6));
mu0 = str2double(answer(7));
mu1 = str2double(answer(8));

T = 0.5*C;
T1 = 0.5*C1;

% Stress tensor, Center, and Radius of Circle
S = [str2double(answer(1)) 0 0 ; 0 str2double(answer(2)) 0; 0 0 str2double(answer(3))];
Center = (S(1,1)+S(3,3))/2;
R = (S(1,1)-S(3,3))/2;

% Mohr-Coulomb failure line for intact rock

sigma_MC = [0:Center+1.25*R];
tau_MC = C + mu0*sigma_MC;

plot(sigma_MC,tau_MC,'b','LineWidth',2);

hold on;

% Mohr-Coulomb failure line for fractures

tau_MC = C1 + mu1*sigma_MC;
plot(sigma_MC,tau_MC,'m','LineWidth',2);

legend('Intact Rock','Fractures');

% Griffith failure

sigma_G = [-T:0.1:0];
tau_G = (4*T*sigma_G + 4*T^2).^0.5;

plot(sigma_G,tau_G,'b','LineWidth',2);

sigma_G = [-T1:0.1:0];
tau_G = (4*T1*sigma_G + 4*T1^2).^0.5;
plot(sigma_G,tau_G,'m','LineWidth',2);

% Plot Mohr's circle

c_handle = circle([Center,0],R,100,'-r');
hold on

% Plot other circles to complete 3D Mohr diagram

R2 = (S(1,1)-S(2,2))/2;
C2 = (S(1,1)+S(2,2))/2;
c_handle2 = circle([C2,0],R2,100,'-r');

R3 = (S(2,2)-S(3,3))/2;
C3 = (S(2,2)+S(3,3))/2;
c_handle3 = circle([C3,0],R3,100,'-r');

% Plot Mohr circles after injection

if P > 0;
   c_handle4 = circle([Center-P,0],R,100,'g--');
   c_handle5 = circle([C2-P,0],R2,100,'g--');
   c_handle6 = circle([C3-P,0],R3,100,'g--');
end

plot([0,0],[0,2*R],'k','LineWidth',2);

% Plot options
axis equal

set(c_handle,'LineWidth',2)
set(c_handle2,'LineWidth',2)
set(c_handle3,'LineWidth',2)

if P > 0;
   set(c_handle4,'LineWidth',2)
   set(c_handle5,'LineWidth',2)
   set(c_handle6,'LineWidth',2)
end

ylim([0, 2*R])
xlim([-C, Center+1.25*R])
%plot([Center-1.25*R, Center+1.25*R],[0, 0],'k-') % line through 0 tau

% Annotate graph

text(Center+1.1*R,R/12,'\sigma_{1}',...
     'HorizontalAlignment','center','FontSize',14)
 text(C2-0.8*R2,R/12,'\sigma_{2}',...
     'HorizontalAlignment','center','FontSize',14)
text(Center-1.1*R,R/12,'\sigma_{3}',...
     'HorizontalAlignment','center','FontSize',14)



%title('Mohr Diagram Before/After Fluid Injection');
xlabel('\sigma_n (MPa)');
ylabel('\tau (MPa)');

% Add stress points for 50 arbitrary planes

for k = 1:50;
    n = rand(1,3);
    n = n/norm(n);
    T = n*S;
    sigma_n = T*n';
    Tnorm = norm(T);
    tau = sqrt(Tnorm^2-sigma_n^2);
    plot(sigma_n,tau,'ro','MarkerFaceColor','r');
    
    if P > 0;
       plot(sigma_n-P,tau,'go','MarkerFaceColor','g');
    end
end

title('Mohr Diagram Showing Random Planes Before (Red) and After (Green) Injection');


